@@ -2,7 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 import vobject
 import urllib
-from DAV.errors import DAV_NotFound, DAV_Forbidden
+from pywebdav.lib.errors import DAV_NotFound, DAV_Forbidden
 from trytond.model import ModelView, ModelSQL
 from trytond.tools import reduce_ids
 from trytond.cache import Cache
@@ -11,6 +11,7 @@ from trytond.pool import Pool
 
 CALDAV_NS = 'urn:ietf:params:xml:ns:caldav'
 
+
 def _comp_filter_domain(dtstart, dtend):
     return ['OR',
         [
@@ -23,37 +24,38 @@ def _comp_filter_domain(dtstart, dtend):
                     ('dtend', '<=', dtend)],
                 [('dtstart', '>=', dtstart),
                     ('dtstart', '<=', dtend),
-                    ('dtend', '=', False)]],
-            ('parent', '=', False),
-            ('rdates', '=', False),
-            ('rrules', '=', False),
-            ('exdates', '=', False),
-            ('exrules', '=', False),
-            ('occurences', '=', False),
+                    ('dtend', '=', None)]],
+            ('parent', '=', None),
+            ('rdates', '=', None),
+            ('rrules', '=', None),
+            ('exdates', '=', None),
+            ('exrules', '=', None),
+            ('occurences', '=', None),
             ],
-        [ #TODO manage better recurring event
-            ('parent', '=', False),
+        [  # TODO manage better recurring event
+            ('parent', '=', None),
             ('dtstart', '<=', dtend),
             ['OR',
-                ('rdates', '!=', False),
-                ('rrules', '!=', False),
-                ('exdates', '!=', False),
-                ('exrules', '!=', False),
-                ('occurences', '!=', False),
+                ('rdates', '!=', None),
+                ('rrules', '!=', None),
+                ('exdates', '!=', None),
+                ('exrules', '!=', None),
+                ('occurences', '!=', None),
                 ]
             ]]
 
+
 class Collection(ModelSQL, ModelView):
 
     _name = "webdav.collection"
 
     def calendar(self, uri, ics=False):
         '''
-        Return the calendar id in the uri or False
+        Return the calendar id in the uri
 
         :param uri: the uri
         :return: calendar id
-            or False if there is no calendar
+            or None if there is no calendar
         '''
         calendar_obj = Pool().get('calendar.calendar')
 
@@ -63,19 +65,18 @@ class Collection(ModelSQL, ModelView):
                 if calendar.endswith('.ics'):
                     calendar = calendar[:-4]
                 else:
-                    return False
+                    return None
             return calendar_obj.get_name(calendar)
-        return False
 
     @Cache('webdav_collection.event')
     def event(self, uri, calendar_id=False):
         '''
-        Return the event id in the uri or False
+        Return the event id in the uri
 
         :param uri: the uri
         :param calendar_id: the calendar id
         :return: event id
-            or False if there is no event
+            or None if there is no event
         '''
         event_obj = Pool().get('calendar.event')
 
@@ -84,15 +85,14 @@ class Collection(ModelSQL, ModelView):
             if not calendar_id:
                 calendar_id = self.calendar(uri)
                 if not calendar_id:
-                    return False
+                    return None
             event_ids = event_obj.search([
                 ('calendar', '=', calendar_id),
                 ('uuid', '=', event_uri[:-4]),
-                ('parent', '=', False),
+                ('parent', '=', None),
                 ], limit=1)
             if event_ids:
                 return event_ids[0]
-        return False
 
     def _caldav_filter_domain_calendar(self, filter):
         '''
@@ -186,8 +186,11 @@ class Collection(ModelSQL, ModelView):
 
         if uri in ('Calendars', 'Calendars/'):
             domain = self._caldav_filter_domain_calendar(filter)
-            domain = [['OR', ('owner', '=', Transaction().user), ('read_users', '=', Transaction().user)],
-                    domain]
+            domain = [['OR',
+                    ('owner', '=', Transaction().user),
+                    ('read_users', '=', Transaction().user),
+                    ],
+                domain]
             calendar_ids = calendar_obj.search(domain)
             calendars = calendar_obj.browse(calendar_ids)
             if cache is not None:
@@ -269,10 +272,10 @@ class Collection(ModelSQL, ModelView):
                     ids = cache['_calendar'][calendar_obj._name].keys()
                     if calendar_id not in ids:
                         ids.append(calendar_id)
-                    elif 'creationdate' in cache['_calendar']\
-                            [calendar_obj._name][calendar_id]:
-                        return cache['_calendar'][calendar_obj._name]\
-                                [calendar_id]['creationdate']
+                    elif 'creationdate' in cache['_calendar'][
+                            calendar_obj._name][calendar_id]:
+                        return cache['_calendar'][calendar_obj._name][
+                            calendar_id]['creationdate']
                 else:
                     ids = [calendar_id]
                 res = None
@@ -290,8 +293,8 @@ class Collection(ModelSQL, ModelView):
                         if cache is not None:
                             cache['_calendar'][calendar_obj._name]\
                                     .setdefault(calendar_id2, {})
-                            cache['_calendar'][calendar_obj._name]\
-                                    [calendar_id2]['creationdate'] = date
+                            cache['_calendar'][calendar_obj._name][
+                                calendar_id2]['creationdate'] = date
                 if res is not None:
                     return res
             else:
@@ -303,10 +306,10 @@ class Collection(ModelSQL, ModelView):
                         ids = cache['_calendar'][event_obj._name].keys()
                         if event_id not in ids:
                             ids.append(event_id)
-                        elif 'creationdate' in cache['_calendar']\
-                                [event_obj._name][event_id]:
-                            return cache['_calendar'][event_obj._name]\
-                                    [event_id]['creationdate']
+                        elif 'creationdate' in cache['_calendar'][
+                                event_obj._name][event_id]:
+                            return cache['_calendar'][event_obj._name][
+                                event_id]['creationdate']
                     else:
                         ids = [event_id]
                     res = None
@@ -324,8 +327,8 @@ class Collection(ModelSQL, ModelView):
                             if cache is not None:
                                 cache['_calendar'][event_obj._name]\
                                         .setdefault(event_id2, {})
-                                cache['_calendar'][event_obj._name]\
-                                        [event_id2]['creationdate'] = date
+                                cache['_calendar'][event_obj._name][
+                                    event_id2]['creationdate'] = date
                     if res is not None:
                         return res
         return super(Collection, self).get_creationdate(uri, cache=cache)
@@ -344,10 +347,10 @@ class Collection(ModelSQL, ModelView):
                     ids = cache['_calendar'][calendar_obj._name].keys()
                     if calendar_id not in ids:
                         ids.append(calendar_id)
-                    elif 'lastmodified' in cache['_calendar']\
-                            [calendar_obj._name][calendar_id]:
-                        return cache['_calendar'][calendar_obj._name]\
-                                [calendar_id]['lastmodified']
+                    elif 'lastmodified' in cache['_calendar'][
+                            calendar_obj._name][calendar_id]:
+                        return cache['_calendar'][calendar_obj._name][
+                            calendar_id]['lastmodified']
                 else:
                     ids = [calendar_id]
                 res = None
@@ -365,8 +368,8 @@ class Collection(ModelSQL, ModelView):
                         if cache is not None:
                             cache['_calendar'][calendar_obj._name]\
                                     .setdefault(calendar_id2, {})
-                            cache['_calendar'][calendar_obj._name]\
-                                    [calendar_id2]['lastmodified'] = date
+                            cache['_calendar'][calendar_obj._name][
+                                calendar_id2]['lastmodified'] = date
                 if res is not None:
                     return res
             else:
@@ -378,15 +381,15 @@ class Collection(ModelSQL, ModelView):
                         ids = cache['_calendar'][event_obj._name].keys()
                         if event_id not in ids:
                             ids.append(event_id)
-                        elif 'lastmodified' in cache['_calendar']\
-                                [event_obj._name][event_id]:
-                            return cache['_calendar'][event_obj._name]\
-                                    [event_id]['lastmodified']
+                        elif 'lastmodified' in cache['_calendar'][
+                                event_obj._name][event_id]:
+                            return cache['_calendar'][event_obj._name][
+                                event_id]['lastmodified']
                     else:
                         ids = [event_id]
                     res = None
-                    for i in range(0, len(ids), cursor.IN_MAX/2):
-                        sub_ids = ids[i:i + cursor.IN_MAX/2]
+                    for i in range(0, len(ids), cursor.IN_MAX / 2):
+                        sub_ids = ids[i:i + cursor.IN_MAX / 2]
                         red_id_sql, red_id_ids = reduce_ids('id', sub_ids)
                         red_parent_sql, red_parent_ids = reduce_ids('parent',
                                 sub_ids)
@@ -404,8 +407,8 @@ class Collection(ModelSQL, ModelView):
                             if cache is not None:
                                 cache['_calendar'][event_obj._name]\
                                         .setdefault(event_id2, {})
-                                cache['_calendar'][event_obj._name]\
-                                        [event_id2]['lastmodified'] = date
+                                cache['_calendar'][event_obj._name][
+                                    event_id2]['lastmodified'] = date
                     if res is not None:
                         return res
         calendar_ics_id = self.calendar(uri, ics=True)
@@ -416,10 +419,10 @@ class Collection(ModelSQL, ModelView):
                 ids = cache['_calendar'][calendar_obj._name].keys()
                 if calendar_ics_id not in ids:
                     ids.append(calendar_ics_id)
-                elif 'lastmodified ics' in cache['_calendar']\
-                        [calendar_obj._name][calendar_ics_id]:
-                    return cache['_calendar'][calendar_obj._name]\
-                            [calendar_ics_id]['lastmodified ics']
+                elif 'lastmodified ics' in cache['_calendar'][
+                        calendar_obj._name][calendar_ics_id]:
+                    return cache['_calendar'][calendar_obj._name][
+                        calendar_ics_id]['lastmodified ics']
             else:
                 ids = [calendar_ics_id]
             res = None
@@ -437,8 +440,8 @@ class Collection(ModelSQL, ModelView):
                     if cache is not None:
                         cache['_calendar'][calendar_obj._name]\
                                 .setdefault(calendar_id2, {})
-                        cache['_calendar'][calendar_obj._name]\
-                                [calendar_id2]['lastmodified ics'] = date
+                        cache['_calendar'][calendar_obj._name][
+                            calendar_id2]['lastmodified ics'] = date
             if res is not None:
                 return res
         return super(Collection, self).get_lastmodified(uri, cache=cache)
@@ -474,10 +477,10 @@ class Collection(ModelSQL, ModelView):
                     ids = cache['_calendar'][calendar_obj._name].keys()
                     if calendar_id not in ids:
                         ids.append(calendar_id)
-                    elif 'calendar_description' in cache['_calendar']\
-                            [calendar_obj._name][calendar_id]:
-                        res = cache['_calendar'][calendar_obj._name]\
-                                [calendar_id]['calendar_description']
+                    elif 'calendar_description' in cache['_calendar'][
+                            calendar_obj._name][calendar_id]:
+                        res = cache['_calendar'][calendar_obj._name][
+                            calendar_id]['calendar_description']
                         if res is not None:
                             return res
                 else:
@@ -489,8 +492,8 @@ class Collection(ModelSQL, ModelView):
                     if cache is not None:
                         cache['_calendar'][calendar_obj._name]\
                                 .setdefault(calendar.id, {})
-                        cache['_calendar'][calendar_obj._name]\
-                                [calendar.id]['calendar_description'] = \
+                        cache['_calendar'][calendar_obj._name][
+                            calendar.id]['calendar_description'] = \
                                 calendar.description
                 if res is not None:
                     return res
